@@ -1,5 +1,5 @@
 
-import os
+import subprocess
 
 class Request:
     def __init__(self, url="", headers={}, body={}):
@@ -29,20 +29,20 @@ class Request:
 
     def GET(self):
         curl = ["curl", "-XGET"] + self.__getHeadersRequest() + [self.__url]
-        result = os.system(' '.join(curl))
+        result = subprocess.check_output(' '.join(curl), shell=True, stderr=subprocess.STDOUT)
         return result
 
     def POST(self):
         curl = ["curl", "-XPOST", "-d", self.__getBodyRequest()] + self.__getHeadersRequest() + [self.__url]
-        result = os.system(' '.join(curl))
+        result = subprocess.check_output(' '.join(curl), shell=True, stderr=subprocess.STDOUT)
         return result
 
     def PUT(self):
         curl = ["curl", "-XPUT", "-d", self.__getBodyRequest()] + self.__getHeadersRequest() + [self.__url]
-        result = os.system(' '.join(curl))
+        result = subprocess.check_output(' '.join(curl), shell=True, stderr=subprocess.STDOUT)
         return result
 
     def DELETE(self):
         curl = ["curl", "-XDELETE"] + self.__getHeadersRequest() + [self.__url]
-        result = os.system(' '.join(curl))
+        result = subprocess.check_output(' '.join(curl), shell=True, stderr=subprocess.STDOUT)
         return result
